From 760c2877f56d216078e4c5f2afeead65aa8ad2b4 Mon Sep 17 00:00:00 2001
From: Wang Ziming <wangziming@huawei.com>
Date: Wed, 3 Jun 2020 17:37:32 +0800
Subject: [PATCH 77/77] sriov: Add new ethernet driver hinic to adapt to
 arrch64 platform.

Add new ethernet driver hinic to adapt to arrch64 platform, and do not
need to add pci bridge controller in arrch64 platform.

Signed-off-by: Wang Ziming <wangziming@huawei.com>
Signed-off-by: Chen Qun <kuhn.chenqun@huawei.com>
---
 libvirt/tests/cfg/sriov/sriov.cfg |  2 ++
 libvirt/tests/src/sriov/sriov.py  | 12 +++++++++---
 2 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/libvirt/tests/cfg/sriov/sriov.cfg b/libvirt/tests/cfg/sriov/sriov.cfg
index 991f7b22..9599a58e 100644
--- a/libvirt/tests/cfg/sriov/sriov.cfg
+++ b/libvirt/tests/cfg/sriov/sriov.cfg
@@ -13,6 +13,8 @@
                     driver = be2net
                 - mlx:
                     driver = mlx4_core
+                - hinic:
+                    driver = hinic
                 - enic:
                     driver = enic
                 - i40e:
diff --git a/libvirt/tests/src/sriov/sriov.py b/libvirt/tests/src/sriov/sriov.py
index 9aec80fc..7d07a21c 100644
--- a/libvirt/tests/src/sriov/sriov.py
+++ b/libvirt/tests/src/sriov/sriov.py
@@ -4,6 +4,7 @@ import re
 import glob
 import string
 import random
+import platform
 
 from avocado.utils import process
 
@@ -37,6 +38,8 @@ def run(test, params, env):
                 pf_iface_name = temp_iface_name
                 pci_address = pci
                 break
+            else:
+                pci_address = pci
         if pci_address == "":
             return False
         else:
@@ -147,6 +150,7 @@ def run(test, params, env):
         """
         Get interface IP address by given MAC address.
         """
+        iface_name = None
         if vm.serial_console is not None:
             vm.cleanup_serial_console()
         vm.create_serial_console()
@@ -263,10 +267,12 @@ def run(test, params, env):
             xml = NodedevXML.new_from_dumpxml(nodedev_pci)
             if info_type == "pf_info":
                 product_info = xml.cap.product_info
-                max_count = xml.max_count
+                max_count = int(xml.max_count)
+                if "aarch64" in platform.platform():
+                    max_count -= 1
                 if pci_info.find(product_info) == -1:
                     test.fail("The product_info show in nodedev-dumpxml is wrong\n")
-                if int(max_count) != max_vfs:
+                if max_count != max_vfs:
                     test.fail("The maxCount show in nodedev-dumpxml is wrong\n")
             if info_type == "vf_order":
                 vf_addr_list = xml.cap.virt_functions
@@ -610,7 +616,7 @@ def run(test, params, env):
             logging.debug(device)
             if device.type == 'pci' and device.model == "pci-bridge":
                 pci_bridge_controllers.append(device)
-        if not pci_bridge_controllers:
+        if not pci_bridge_controllers and "aarch64" not in platform.platform():
             pci_bridge_controller = Controller("controller")
             pci_bridge_controller.type = "pci"
             pci_bridge_controller.index = "1"
-- 
2.23.0

